@@ -14,7 +14,7 @@ use utf8;
 package Dist::Zilla::Plugin::WSDL;
 
 BEGIN {
-    $Dist::Zilla::Plugin::WSDL::VERSION = '0.201';
+    $Dist::Zilla::Plugin::WSDL::VERSION = '0.202';
 }
 
 # ABSTRACT: WSDL to Perl classes when building your dist
@@ -39,30 +39,24 @@ with 'Dist::Zilla::Role::BeforeBuild';
 
 has uri => ( ro, required, coerce, isa => Uri );
 
-has _definitions => (
-    ro, lazy_build,
-    isa      => 'SOAP::WSDL::Base',
-    init_arg => undef,
-);
+has _definitions => ( ro, lazy_build, isa => 'SOAP::WSDL::Base' );
 
 sub _build__definitions {    ## no critic (ProhibitUnusedPrivateSubroutines)
     my $self = shift;
 
     my $lwp = LWP::UserAgent->new();
     $lwp->env_proxy();
+
     my $parser = SOAP::WSDL::Expat::WSDLParser->new( { user_agent => $lwp } );
-    return $parser->parse_uri( $self->uri() );
+    my $wsdl = $parser->parse_uri( $self->uri )
+        or $self->zilla->log_fatal('could not parse WSDL');
+
+    return $wsdl;
 }
 
-has _OUTPUT_PATH => (
-    ro,
-    isa      => Str,
-    default  => q{.},
-    init_arg => undef,
-);
+has _OUTPUT_PATH => ( ro, isa => Str, default => q{.} );
 
-has prefix => (
-    ro,
+has prefix => ( ro,
     isa       => ClassPrefix,
     predicate => 'has_prefix',
     default   => 'My',
@@ -80,15 +74,14 @@ has _typemap_lines => ( ro,
 
 has _typemap => ( ro, lazy_build,
     isa => HashRef [Str],
-    traits   => ['Hash'],
-    init_arg => undef,
-    handles  => { _has__typemap => 'count' },
+    traits  => ['Hash'],
+    handles => { _has__typemap => 'count' },
 );
 
 sub _build__typemap {    ## no critic (ProhibitUnusedPrivateSubroutines)
     my $self = shift;
 
-    return { map { +split / \s* => \s* /, $ARG } $self->_typemap_array() };
+    return { map { +split / \s* => \s* /, $ARG } $self->_typemap_array };
 }
 
 has _generator =>
@@ -100,7 +93,7 @@ sub _build__generator {    ## no critic (ProhibitUnusedPrivateSubroutines)
     my $generator
         = SOAP::WSDL::Factory::Generator->get_generator( { type => 'XSD' } );
     if ( $self->_has__typemap and $generator->can('set_typemap') ) {
-        $generator->set_typemap( $self->_typemap() );
+        $generator->set_typemap( $self->_typemap );
     }
 
     my %prefix_method = map { ( $ARG => "set_${ARG}_prefix" ) }
@@ -122,11 +115,7 @@ sub _build__generator {    ## no critic (ProhibitUnusedPrivateSubroutines)
     return $generator;
 }
 
-has generate_server => (
-    ro,
-    isa     => Bool,
-    default => 0,
-);
+has generate_server => ( ro, isa => Bool, default => 0 );
 
 sub before_build {
     my $self = shift;
@@ -158,6 +147,8 @@ sub before_build {
 
 1;
 
+__END__
+
 =pod
 
 =for :stopwords Mark Gardner GSI Commerce cpan testmatrix url annocpan anno bugtracker rt
@@ -169,7 +160,7 @@ Dist::Zilla::Plugin::WSDL - WSDL to Perl classes when building your dist
 
 =head1 VERSION
 
-version 0.201
+version 0.202
 
 =head1 DESCRIPTION
 
@@ -315,5 +306,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-__END__
